#!/usr/bin/python
# -*- coding: UTF-8 -*-
"""
@author: LiangChao
@email：liang20201101@163.com
@desc: 
"""

DEFAULT_TIME_FORMAT = '%Y-%m-%d %H:%M:%S'
